/* This file is part of the KDE project
   Copyright 2010 Marijn Kruisselbrink <m.kruisselbrink@student.tue.nl>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

// Local
#include "FoCellToolFactory.h"

#include <klocale.h>

#include "FoCellTool.h"

FoCellToolFactory::FoCellToolFactory(QObject* parent)
        : KoToolFactoryBase(parent, "FreOfficeCellToolId"),
        m_cellTool(0)
{
    setToolTip(i18n("Cell Tool"));
    setIcon("kspread");
    setToolType("KSpread");
    setPriority(0);
    setActivationShapeId("flake/always");
}

FoCellToolFactory::~FoCellToolFactory()
{
}

KoToolBase* FoCellToolFactory::createTool(KoCanvasBase* canvas)
{
    FoCellTool *cellTool=new FoCellTool(canvas);
    if(!m_cellTool) {
        m_cellTool=cellTool;
    }
    return cellTool;
}

FoCellTool *FoCellToolFactory::cellTool()
{
    return m_cellTool;
}
